@@ -4,12 +4,14 @@ use warnings;
 use strict;
 use 5.008003;
 
-our $VERSION = '1.732';
+our $VERSION = '1.733';
 
 use Exporter qw( import );
 
 our @EXPORT_OK = qw( validate_options );
 
+use Carp qw( croak );
+
 
 sub validate_options {
     my ( $valid, $opt ) = @_;
@@ -18,25 +20,28 @@ sub validate_options {
     $sub =~ s/^.+::(?:__)?([^:]+)\z/$1/;
     for my $key ( keys %$opt ) {
         if ( ! exists $valid->{$key} ) {
-            die "$sub: '$key' is not a valid option name";
+            croak "$sub: '$key' is not a valid option name";
         }
         next if ! defined $opt->{$key};
         if ( $valid->{$key} =~ /^Array/ ) {
-            die "$sub: option '$key' => the passed value has to be an ARRAY reference." if ref $opt->{$key} ne 'ARRAY';
+            croak "$sub: option '$key' => the passed value has to be an ARRAY reference." if ref $opt->{$key} ne 'ARRAY';
             if ( $valid->{$key} eq 'Array_Int' ) {
                 no warnings 'uninitialized';
                 for ( @{$opt->{$key}} ) {
-                    /^[0-9]+\z/ or die "$sub: option '$key' => $_ is an invalid array element";
+                    /^[0-9]+\z/ or croak "$sub: option '$key' => $_ is an invalid array element";
                 }
             }
         }
+        elsif ( $valid->{$key} =~ /^Regexp/ ) {                                                                                                # Term::TablePrint prior to 0.138 use a string instead of a compiled regex
+        #    croak "$sub: option '$key' => the passed value has to be a regex quoted with the 'qr' operator." if ref $opt->{$key} ne 'Regexp'; # 22.06.2021  uncomment this after some time
+        }
         elsif ( ref $opt->{$key} ) {
-            die "$sub: option '$key' => a reference is not a valid value.";
+            croak "$sub: option '$key' => a reference is not a valid value.";
         }
         elsif ( $valid->{$key} eq 'Str' ) {
         }
         elsif ( $opt->{$key} !~ m/^$valid->{$key}\z/x ) {
-            die "$sub: option '$key' => '$opt->{$key}' is not a valid value.";
+            croak "$sub: option '$key' => '$opt->{$key}' is not a valid value.";
         }
     }
 }
